"""LICENSE
Copyright 2020 Hermann Krumrey <hermann@krumreyh.com>

This file is part of jerrycan.

jerrycan is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

jerrycan is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jerrycan.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from jerrycan.test.TestFramework import _TestFramework
from jerrycan.db.TelegramChatId import TelegramChatId


class TestRegisterTelegramRoute(_TestFramework):
    """
    Class that tests the route used to register telegram chat IDs
    """

    def test_registering(self):
        """
        Tests registering a telegram chat ID
        :return: None
        """
        user, password, _ = self.generate_sample_user()
        self.assertEqual(len(TelegramChatId.query.all()), 0)
        with self.client:
            self.login_user(user, password)
            self.client.post("/register_telegram",
                             data={"telegram_chat_id": 12345})
            self.assertEqual(len(TelegramChatId.query.all()), 1)
            self.client.post("/register_telegram",
                             data={"telegram_chat_id": 67890})
            self.assertEqual(len(TelegramChatId.query.all()), 1)



"""LICENSE
Copyright 2020 Hermann Krumrey <hermann@krumreyh.com>

This file is part of jerrycan.

jerrycan is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

jerrycan is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with jerrycan.  If not, see <http://www.gnu.org/licenses/>.
LICENSE"""

from jerrycan.base import db
from jerrycan.db.ModelMixin import ModelMixin


class IDModelMixin(ModelMixin):
    """
    A mixin class that specifies a couple of methods all database
    models should implement.
    Includes an automatically incrementing ID.
    """

    id = db.Column(
        db.Integer, primary_key=True, nullable=False, autoincrement=True
    )
    """
    The ID is the primary key of the table and increments automatically
    """

    def __hash__(self) -> int:
        """
        Creates a hash so that the model objects can be used as keys
        :return: None
        """
        return hash(self.id)
